/hg/gfx-test: Another update of BitBltUsingBgColor.

ptisnovs at icedtea.classpath.org ptisnovs at icedtea.classpath.org
Tue Jun 9 09:30:41 UTC 2015


changeset 7ff969ef2f75 in /hg/gfx-test
details: http://icedtea.classpath.org/hg/gfx-test?cmd=changeset;node=7ff969ef2f75
author: Pavel Tisnovsky <ptisnovs at redhat.com>
date: Tue Jun 09 11:33:07 2015 +0200

	Another update of BitBltUsingBgColor.


diffstat:

 ChangeLog                                          |    5 +
 src/org/gfxtest/testsuites/BitBltUsingBgColor.java |  128 ++++++++++----------
 2 files changed, 69 insertions(+), 64 deletions(-)

diffs (213 lines):

diff -r a37fe0795223 -r 7ff969ef2f75 ChangeLog
--- a/ChangeLog	Mon Jun 08 13:32:45 2015 +0200
+++ b/ChangeLog	Tue Jun 09 11:33:07 2015 +0200
@@ -1,3 +1,8 @@
+2015-06-09  Pavel Tisnovsky  <ptisnovs at redhat.com>
+
+	* src/org/gfxtest/testsuites/BitBltUsingBgColor.java:
+	Another update of BitBltUsingBgColor.
+
 2015-06-08  Pavel Tisnovsky  <ptisnovs at redhat.com>
 
 	* src/org/gfxtest/testsuites/BitBltUsingBgColor.java:
diff -r a37fe0795223 -r 7ff969ef2f75 src/org/gfxtest/testsuites/BitBltUsingBgColor.java
--- a/src/org/gfxtest/testsuites/BitBltUsingBgColor.java	Mon Jun 08 13:32:45 2015 +0200
+++ b/src/org/gfxtest/testsuites/BitBltUsingBgColor.java	Tue Jun 09 11:33:07 2015 +0200
@@ -13096,7 +13096,7 @@
     }
 
     /**
      * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_USHORT_555_RGB.
      * Background color is set to Color.yellow.
      *
      * @param image
@@ -13105,13 +13105,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltDiagonalCheckerBufferedImageTypeUshort555RGBBackgroundYellow(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltDiagonalCheckerBufferedImageTypeUshort555RGB(image, graphics2d, Color.yellow);
-    }
-
-    /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_USHORT_555_RGB.
+    public TestResult testBitBltGridBufferedImageTypeIntARGBbackgroundYellow(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltGridBufferedImageTypeIntARGB(image, graphics2d, Color.yellow);
+    }
+
+    /**
+     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_INT_ARGB}.
      * Background color is set to Color.white.
      *
      * @param image
@@ -13120,13 +13120,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltDiagonalCheckerBufferedImageTypeUshort555RGBBackgroundWhite(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltDiagonalCheckerBufferedImageTypeUshort555RGB(image, graphics2d, Color.white);
-    }
-
-    /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_USHORT_565_RGB.
+    public TestResult testBitBltGridBufferedImageTypeIntARGBbackgroundWhite(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltGridBufferedImageTypeIntARGB(image, graphics2d, Color.white);
+    }
+
+    /**
+     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_INT_ARGB_PRE}.
      * Background color is set to Color.black.
      *
      * @param image
@@ -13135,13 +13135,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltDiagonalCheckerBufferedImageTypeUshort565RGBBackgroundBlack(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltDiagonalCheckerBufferedImageTypeUshort565RGB(image, graphics2d, Color.black);
-    }
-
-    /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_USHORT_565_RGB.
+    public TestResult testBitBltGridBufferedImageTypeIntARGB_Pre_backgroundBlack(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltGridBufferedImageTypeIntARGB_Pre(image, graphics2d, Color.black);
+    }
+
+    /**
+     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_INT_ARGB_PRE}.
      * Background color is set to Color.blue.
      *
      * @param image
@@ -13150,13 +13150,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltDiagonalCheckerBufferedImageTypeUshort565RGBBackgroundBlue(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltDiagonalCheckerBufferedImageTypeUshort565RGB(image, graphics2d, Color.blue);
-    }
-
-    /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_USHORT_565_RGB.
+    public TestResult testBitBltGridBufferedImageTypeIntARGB_Pre_backgroundBlue(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltGridBufferedImageTypeIntARGB_Pre(image, graphics2d, Color.blue);
+    }
+
+    /**
+     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_INT_ARGB_PRE}.
      * Background color is set to Color.green.
      *
      * @param image
@@ -13165,13 +13165,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltDiagonalCheckerBufferedImageTypeUshort565RGBBackgroundGreen(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltDiagonalCheckerBufferedImageTypeUshort565RGB(image, graphics2d, Color.green);
-    }
-
-    /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_USHORT_565_RGB.
+    public TestResult testBitBltGridBufferedImageTypeIntARGB_Pre_backgroundGreen(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltGridBufferedImageTypeIntARGB_Pre(image, graphics2d, Color.green);
+    }
+
+    /**
+     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_INT_ARGB_PRE}.
      * Background color is set to Color.cyan.
      *
      * @param image
@@ -13180,13 +13180,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltDiagonalCheckerBufferedImageTypeUshort565RGBBackgroundCyan(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltDiagonalCheckerBufferedImageTypeUshort565RGB(image, graphics2d, Color.cyan);
-    }
-
-    /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_USHORT_565_RGB.
+    public TestResult testBitBltGridBufferedImageTypeIntARGB_Pre_backgroundCyan(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltGridBufferedImageTypeIntARGB_Pre(image, graphics2d, Color.cyan);
+    }
+
+    /**
+     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_INT_ARGB_PRE}.
      * Background color is set to Color.red.
      *
      * @param image
@@ -13195,13 +13195,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltDiagonalCheckerBufferedImageTypeUshort565RGBBackgroundRed(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltDiagonalCheckerBufferedImageTypeUshort565RGB(image, graphics2d, Color.red);
-    }
-
-    /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_USHORT_565_RGB.
+    public TestResult testBitBltGridBufferedImageTypeIntARGB_Pre_backgroundRed(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltGridBufferedImageTypeIntARGB_Pre(image, graphics2d, Color.red);
+    }
+
+    /**
+     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_INT_ARGB_PRE}.
      * Background color is set to Color.magenta.
      *
      * @param image
@@ -13210,13 +13210,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltDiagonalCheckerBufferedImageTypeUshort565RGBBackgroundMagenta(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltDiagonalCheckerBufferedImageTypeUshort565RGB(image, graphics2d, Color.magenta);
-    }
-
-    /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_USHORT_565_RGB.
+    public TestResult testBitBltGridBufferedImageTypeIntARGB_Pre_backgroundMagenta(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltGridBufferedImageTypeIntARGB_Pre(image, graphics2d, Color.magenta);
+    }
+
+    /**
+     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_INT_ARGB_PRE}.
      * Background color is set to Color.yellow.
      *
      * @param image
@@ -13225,13 +13225,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltDiagonalCheckerBufferedImageTypeUshort565RGBBackgroundYellow(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltDiagonalCheckerBufferedImageTypeUshort565RGB(image, graphics2d, Color.yellow);
-    }
-
-    /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_USHORT_565_RGB.
+    public TestResult testBitBltGridBufferedImageTypeIntARGB_Pre_backgroundYellow(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltGridBufferedImageTypeIntARGB_Pre(image, graphics2d, Color.yellow);
+    }
+
+    /**
+     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_INT_ARGB_PRE}.
      * Background color is set to Color.white.
      *
      * @param image
@@ -13096,7 +13096,7 @@
 
     /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_USHORT_555_RGB.
+     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_INT_ARGB}.
      * Background color is set to Color.yellow.
      *


More information about the distro-pkg-dev mailing list